==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-barChart.dart <==
/*

Imports:

charts_flutter: ^0.9.0 dependency is added to pubspec.yaml file.
import 'package:charts_flutter/flutter.dart' as charts;
import 'custom-barChart.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

Usage:

- Defining the callback and Bar Graph objects


List<GrantsData> barGraphData = [
      new GrantsData('Jan', 5,Colors.grey),
      new GrantsData('Feb', 2, Colors.orange),
      new GrantsData('Mar', 1, Colors.black),
      new GrantsData('Apr', 4, Colors.red),
    ];


    List<charts.Series<GrantsData, String>> barSeries = [
    new charts.Series<GrantsData, String>(
    id: 'Sales',
    domainFn: (GrantsData sales, _) => sales.year,
    measureFn: (GrantsData sales, _) => sales.grants,
    colorFn: (GrantsData sales, _) =>
    charts.ColorUtil.fromDartColor(sales.mColor),
    labelAccessorFn: (GrantsData row, _) => '${row.grants}',
    data: barGraphData,
    )
    ];

    ChartsBar objBarOne = new ChartsBar(barSeries);

- Object call for the widget


  body:objBarOne



*/
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'consts.dart' as con;

class ChartsBar extends StatefulWidget{
  List<charts.Series<dynamic,dynamic>> chartData;
  ChartsBar(this.chartData);

  @override
  State<StatefulWidget> createState() {
    return _chartsbar(chartData);
  }

}

class _chartsbar extends State<ChartsBar>{
  List<charts.Series<dynamic,dynamic>> chartData;

  _chartsbar(this.chartData);


  @override
  Widget build(BuildContext context) {
    return _CreateBarChart(chartData);
  }

  Widget _CreateBarChart(List<charts.Series<dynamic,dynamic>> objSeries)
  {
    charts.BarChart mBarChart;
    mBarChart = new charts.BarChart(objSeries,
      animate:true ,
      animationDuration: Duration(seconds: con.intTwo),
      behaviors: [
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: con.intOne,
        )
      ],
      defaultRenderer: new charts.BarRendererConfig(

      ),
    );

    return mBarChart;
  }


}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-barChart.dart <==
/*

Imports:

charts_flutter: ^0.9.0 dependency is added to pubspec.yaml file.
import 'package:charts_flutter/flutter.dart' as charts;
import 'custom-barChart.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

Usage:

- Defining the callback and Bar Graph objects


List<GrantsData> barGraphData = [
      new GrantsData('Jan', 5,Colors.grey),
      new GrantsData('Feb', 2, Colors.orange),
      new GrantsData('Mar', 1, Colors.black),
      new GrantsData('Apr', 4, Colors.red),
    ];


    List<charts.Series<GrantsData, String>> barSeries = [
    new charts.Series<GrantsData, String>(
    id: 'Sales',
    domainFn: (GrantsData sales, _) => sales.year,
    measureFn: (GrantsData sales, _) => sales.grants,
    colorFn: (GrantsData sales, _) =>
    charts.ColorUtil.fromDartColor(sales.mColor),
    labelAccessorFn: (GrantsData row, _) => '${row.grants}',
    data: barGraphData,
    )
    ];

    ChartsBar objBarOne = new ChartsBar(barSeries);

- Object call for the widget


  body:objBarOne



*/
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'consts.dart' as con;

class ChartsBar extends StatefulWidget{
  final List<charts.Series<dynamic,dynamic>> chartData;
  ChartsBar(this.chartData);

  @override
  State<StatefulWidget> createState() {
    return _Chartsbar(chartData);
  }

}

class _Chartsbar extends State<ChartsBar>{
  List<charts.Series<dynamic,dynamic>> chartData;

  _Chartsbar(this.chartData);


  @override
  Widget build(BuildContext context) {
    return _createBarChart(chartData);
  }

  Widget _createBarChart(List<charts.Series<dynamic,dynamic>> objSeries)
  {
    charts.BarChart mBarChart;
    mBarChart = new charts.BarChart(objSeries,
      animate:true ,
      animationDuration: Duration(seconds: con.intTwo),
      behaviors: [
        new charts.DatumLegend(
          position: charts.BehaviorPosition.bottom,
          outsideJustification: charts.OutsideJustification.middleDrawArea,
          horizontalFirst: false,
          desiredMaxRows: con.intOne,
        )
      ],
      defaultRenderer: new charts.BarRendererConfig(

      ),
    );

    return mBarChart;
  }


}
